.. Stupeflask documentation master file, created by
   sphinx-quickstart on Sat Feb 10 19:11:24 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

Documentation
=============

.. toctree::
   :maxdepth: 2

   application
   config
   objectid
   reference
   cursor

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _marshmallow: https://marshmallow.readthedocs.io/en/latest/
.. _mongodb: https://www.mongodb.com/
